"""
Generated class for ConceptMap. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.Coding import *
from fhirmodels.R5.ContactDetail import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Period import *
from fhirmodels.R5.Quantity import *
from fhirmodels.R5.RelatedArtifact import *
from fhirmodels.R5.Resource import *
from fhirmodels.R5.UsageContext import *


class Property(FhirBaseModel):
    """A property defines a slot through which additional information can be provided about a map from source -> target.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str code: Identifies the property on the mappings, and when referred to in the $translate operation
    :param str uri: Formal identifier for the property
    :param str description: Why the property is defined, and/or what it conveys
    :param str type: Coding | string | integer | boolean | dateTime | decimal | code
    :param str system: The CodeSystem from which code values come
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        code: "str" = None,
        uri: "str" = None,
        description: "str" = None,
        type: "str" = None,
        system: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.code = code
        self.uri = uri
        self.description = description
        self.type = type
        self.system = system

    @classmethod
    def from_dict(cls, data: dict) -> "ConceptMap":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ConceptMap":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class AdditionalAttribute(FhirBaseModel):
    """An additionalAttribute defines an additional data element found in the source or target data model where the data will come from or be mapped to. Some mappings are based on data in addition to the source data element, where codes in multiple fields are combined to a single field (or vice versa).:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str code: Identifies this additional attribute through this resource
    :param str uri: Formal identifier for the data element referred to in this attribte
    :param str description: Why the additional attribute is defined, and/or what the data element it refers to is
    :param str type: code | Coding | string | boolean | Quantity
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        code: "str" = None,
        uri: "str" = None,
        description: "str" = None,
        type: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.code = code
        self.uri = uri
        self.description = description
        self.type = type

    @classmethod
    def from_dict(cls, data: dict) -> "ConceptMap":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ConceptMap":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Property(FhirBaseModel):
    """A property value for this source -> target mapping.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str code: Reference to ConceptMap.property.code
    :param Coding valueCoding: Value of the property for this concept
    :param str valueString: Value of the property for this concept
    :param int valueInteger: Value of the property for this concept
    :param bool valueBoolean: Value of the property for this concept
    :param str valueDateTime: Value of the property for this concept
    :param float valueDecimal: Value of the property for this concept
    :param str valueCode: Value of the property for this concept
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "valueCoding": {"class_name": "Coding", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        code: "str" = None,
        valueCoding: "Coding" = None,
        valueString: "str" = None,
        valueInteger: "int" = None,
        valueBoolean: "bool" = None,
        valueDateTime: "str" = None,
        valueDecimal: "float" = None,
        valueCode: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.code = code
        self.valueCoding = valueCoding
        self.valueString = valueString
        self.valueInteger = valueInteger
        self.valueBoolean = valueBoolean
        self.valueDateTime = valueDateTime
        self.valueDecimal = valueDecimal
        self.valueCode = valueCode

    @classmethod
    def from_dict(cls, data: dict) -> "ConceptMap":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ConceptMap":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class DependsOn(FhirBaseModel):
    """A set of additional dependencies for this mapping to hold. This mapping is only applicable if the specified data attribute can be resolved, and it has the specified value.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str attribute: A reference to a mapping attribute defined in ConceptMap.additionalAttribute
    :param str valueCode: Value of the referenced data element
    :param Coding valueCoding: Value of the referenced data element
    :param str valueString: Value of the referenced data element
    :param bool valueBoolean: Value of the referenced data element
    :param Quantity valueQuantity: Value of the referenced data element
    :param str valueSet: The mapping depends on a data element with a value from this value set
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "valueCoding": {"class_name": "Coding", "is_contained": False},
        "valueQuantity": {"class_name": "Quantity", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        attribute: "str" = None,
        valueCode: "str" = None,
        valueCoding: "Coding" = None,
        valueString: "str" = None,
        valueBoolean: "bool" = None,
        valueQuantity: "Quantity" = None,
        valueSet: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.attribute = attribute
        self.valueCode = valueCode
        self.valueCoding = valueCoding
        self.valueString = valueString
        self.valueBoolean = valueBoolean
        self.valueQuantity = valueQuantity
        self.valueSet = valueSet

    @classmethod
    def from_dict(cls, data: dict) -> "ConceptMap":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ConceptMap":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Target(FhirBaseModel):
    """A concept from the target value set that this concept maps to.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str code: Code that identifies the target element
    :param str display: Display for the code
    :param str valueSet: Identifies the set of target concepts
    :param str relationship: related-to | equivalent | source-is-narrower-than-target | source-is-broader-than-target | not-related-to
    :param str comment: Description of status/issues in mapping
    :param Property property: Property value for the source -> target mapping
    :param DependsOn dependsOn: Other properties required for this mapping
    :param Product product: Other data elements that this mapping also produces
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "property": {"class_name": "Property", "is_contained": True},
        "dependsOn": {"class_name": "DependsOn", "is_contained": True},
        "product": {"class_name": "Product", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        code: "str" = None,
        display: "str" = None,
        valueSet: "str" = None,
        relationship: "str" = None,
        comment: "str" = None,
        property: list["Property"] = None,
        dependsOn: list["DependsOn"] = None,
        product: list["Product"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.code = code
        self.display = display
        self.valueSet = valueSet
        self.relationship = relationship
        self.comment = comment
        self.property = property or []
        self.dependsOn = dependsOn or []
        self.product = product or []

    @classmethod
    def from_dict(cls, data: dict) -> "ConceptMap":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ConceptMap":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Element(FhirBaseModel):
    """Mappings for an individual concept in the source to one or more concepts in the target.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str code: Identifies element being mapped
    :param str display: Display for the code
    :param str valueSet: Identifies the set of concepts being mapped
    :param bool noMap: No mapping to a target concept for this source concept
    :param Target target: Concept in target system for element
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "target": {"class_name": "Target", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        code: "str" = None,
        display: "str" = None,
        valueSet: "str" = None,
        noMap: "bool" = None,
        target: list["Target"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.code = code
        self.display = display
        self.valueSet = valueSet
        self.noMap = noMap
        self.target = target or []

    @classmethod
    def from_dict(cls, data: dict) -> "ConceptMap":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ConceptMap":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Unmapped(FhirBaseModel):
    """What to do when there is no mapping to a target concept from the source concept and ConceptMap.group.element.noMap is not true. This provides the "default" to be applied when there is no target concept mapping specified or the expansion of ConceptMap.group.element.target.valueSet is empty.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str mode: use-source-code | fixed | other-map
    :param str code: Fixed code when mode = fixed
    :param str display: Display for the code
    :param str valueSet: Fixed code set when mode = fixed
    :param str relationship: related-to | equivalent | source-is-narrower-than-target | source-is-broader-than-target | not-related-to
    :param str otherMap: canonical reference to an additional ConceptMap to use for mapping if the source concept is unmapped
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        mode: "str" = None,
        code: "str" = None,
        display: "str" = None,
        valueSet: "str" = None,
        relationship: "str" = None,
        otherMap: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.mode = mode
        self.code = code
        self.display = display
        self.valueSet = valueSet
        self.relationship = relationship
        self.otherMap = otherMap

    @classmethod
    def from_dict(cls, data: dict) -> "ConceptMap":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ConceptMap":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Group(FhirBaseModel):
    """A group of mappings that all have the same source and target system.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str source: Source system where concepts to be mapped are defined
    :param str target: Target system that the concepts are to be mapped to
    :param Element element: Mappings for a concept from the source set
    :param Unmapped unmapped: What to do when there is no mapping target for the source concept and ConceptMap.group.element.noMap is not true
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "element": {"class_name": "Element", "is_contained": True},
        "unmapped": {"class_name": "Unmapped", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        source: "str" = None,
        target: "str" = None,
        element: list["Element"] = None,
        unmapped: "Unmapped" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.source = source
        self.target = target
        self.element = element or []
        self.unmapped = unmapped

    @classmethod
    def from_dict(cls, data: dict) -> "ConceptMap":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ConceptMap":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ConceptMap(DomainResource):
    """A statement of relationships from one set of concepts to one or more other concepts - either concepts in code systems, or data element/data element concepts, or classes in class models.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param str url: Canonical identifier for this concept map, represented as a URI (globally unique)
    :param Identifier identifier: Additional identifier for the concept map
    :param str version: Business version of the concept map
    :param str versionAlgorithmString: How to compare versions
    :param Coding versionAlgorithmCoding: How to compare versions
    :param str name: Name for this concept map (computer friendly)
    :param str title: Name for this concept map (human friendly)
    :param str status: draft | active | retired | unknown
    :param bool experimental: For testing purposes, not real usage
    :param str date: Date last changed
    :param str publisher: Name of the publisher/steward (organization or individual)
    :param ContactDetail contact: Contact details for the publisher
    :param str description: Natural language description of the concept map
    :param UsageContext useContext: The context that the content is intended to support
    :param CodeableConcept jurisdiction: Intended jurisdiction for concept map (if applicable)
    :param str purpose: Why this concept map is defined
    :param str copyright: Use and/or publishing restrictions
    :param str copyrightLabel: Copyright holder and year(s)
    :param str approvalDate: When the ConceptMap was approved by publisher
    :param str lastReviewDate: When the ConceptMap was last reviewed by the publisher
    :param Period effectivePeriod: When the ConceptMap is expected to be used
    :param CodeableConcept topic: E.g. Education, Treatment, Assessment, etc
    :param ContactDetail author: Who authored the ConceptMap
    :param ContactDetail editor: Who edited the ConceptMap
    :param ContactDetail reviewer: Who reviewed the ConceptMap
    :param ContactDetail endorser: Who endorsed the ConceptMap
    :param RelatedArtifact relatedArtifact: Additional documentation, citations, etc
    :param Property property: Additional properties of the mapping
    :param AdditionalAttribute additionalAttribute: Definition of an additional attribute to act as a data source or target
    :param str sourceScopeUri: The source value set that contains the concepts that are being mapped
    :param str sourceScopeCanonical: The source value set that contains the concepts that are being mapped
    :param str targetScopeUri: The target value set which provides context for the mappings
    :param str targetScopeCanonical: The target value set which provides context for the mappings
    :param Group group: Same source and target systems
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "versionAlgorithmCoding": {"class_name": "Coding", "is_contained": False},
        "contact": {"class_name": "ContactDetail", "is_contained": False},
        "useContext": {"class_name": "UsageContext", "is_contained": False},
        "jurisdiction": {"class_name": "CodeableConcept", "is_contained": False},
        "effectivePeriod": {"class_name": "Period", "is_contained": False},
        "topic": {"class_name": "CodeableConcept", "is_contained": False},
        "author": {"class_name": "ContactDetail", "is_contained": False},
        "editor": {"class_name": "ContactDetail", "is_contained": False},
        "reviewer": {"class_name": "ContactDetail", "is_contained": False},
        "endorser": {"class_name": "ContactDetail", "is_contained": False},
        "relatedArtifact": {"class_name": "RelatedArtifact", "is_contained": False},
        "property": {"class_name": "Property", "is_contained": True},
        "additionalAttribute": {
            "class_name": "AdditionalAttribute",
            "is_contained": True,
        },
        "group": {"class_name": "Group", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        url: "str" = None,
        identifier: list["Identifier"] = None,
        version: "str" = None,
        versionAlgorithmString: "str" = None,
        versionAlgorithmCoding: "Coding" = None,
        name: "str" = None,
        title: "str" = None,
        status: "str" = None,
        experimental: "bool" = None,
        date: "str" = None,
        publisher: "str" = None,
        contact: list["ContactDetail"] = None,
        description: "str" = None,
        useContext: list["UsageContext"] = None,
        jurisdiction: list["CodeableConcept"] = None,
        purpose: "str" = None,
        copyright: "str" = None,
        copyrightLabel: "str" = None,
        approvalDate: "str" = None,
        lastReviewDate: "str" = None,
        effectivePeriod: "Period" = None,
        topic: list["CodeableConcept"] = None,
        author: list["ContactDetail"] = None,
        editor: list["ContactDetail"] = None,
        reviewer: list["ContactDetail"] = None,
        endorser: list["ContactDetail"] = None,
        relatedArtifact: list["RelatedArtifact"] = None,
        property: list["Property"] = None,
        additionalAttribute: list["AdditionalAttribute"] = None,
        sourceScopeUri: "str" = None,
        sourceScopeCanonical: "str" = None,
        targetScopeUri: "str" = None,
        targetScopeCanonical: "str" = None,
        group: list["Group"] = None,
    ):

        self.resourceType = "ConceptMap"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.url = url
        self.identifier = identifier or []
        self.version = version
        self.versionAlgorithmString = versionAlgorithmString
        self.versionAlgorithmCoding = versionAlgorithmCoding
        self.name = name
        self.title = title
        self.status = status
        self.experimental = experimental
        self.date = date
        self.publisher = publisher
        self.contact = contact or []
        self.description = description
        self.useContext = useContext or []
        self.jurisdiction = jurisdiction or []
        self.purpose = purpose
        self.copyright = copyright
        self.copyrightLabel = copyrightLabel
        self.approvalDate = approvalDate
        self.lastReviewDate = lastReviewDate
        self.effectivePeriod = effectivePeriod
        self.topic = topic or []
        self.author = author or []
        self.editor = editor or []
        self.reviewer = reviewer or []
        self.endorser = endorser or []
        self.relatedArtifact = relatedArtifact or []
        self.property = property or []
        self.additionalAttribute = additionalAttribute or []
        self.sourceScopeUri = sourceScopeUri
        self.sourceScopeCanonical = sourceScopeCanonical
        self.targetScopeUri = targetScopeUri
        self.targetScopeCanonical = targetScopeCanonical
        self.group = group or []

    @classmethod
    def from_dict(cls, data: dict) -> "ConceptMap":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ConceptMap":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for MetadataResource. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.generator import FhirBaseModel
from fhirmodels.R4.CodeableConcept import *
from fhirmodels.R4.ContactDetail import *
from fhirmodels.R4.Extension import *
from fhirmodels.R4.Meta import *
from fhirmodels.R4.Narrative import *
from fhirmodels.R4.Resource import *
from fhirmodels.R4.UsageContext import *


class MetadataResource(FhirBaseModel):
    """Common Ancestor declaration for conformance and knowledge artifact resources.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param str url: Canonical identifier for this metadata resource, represented as a URI (globally unique)
    :param str version: Business version of the metadata resource
    :param str name: Name for this metadata resource (computer friendly)
    :param str title: Name for this metadata resource (human friendly)
    :param str status: draft | active | retired | unknown
    :param bool experimental: For testing purposes, not real usage
    :param str date: Date last changed
    :param str publisher: Name of the publisher (organization or individual)
    :param ContactDetail contact: Contact details for the publisher
    :param str description: Natural language description of the metadata resource
    :param UsageContext useContext: The context that the content is intended to support
    :param CodeableConcept jurisdiction: Intended jurisdiction for metadata resource (if applicable)
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "contact": {"class_name": "ContactDetail", "is_contained": False},
        "useContext": {"class_name": "UsageContext", "is_contained": False},
        "jurisdiction": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        url: "str" = None,
        version: "str" = None,
        name: "str" = None,
        title: "str" = None,
        status: "str" = None,
        experimental: "bool" = None,
        date: "str" = None,
        publisher: "str" = None,
        contact: list["ContactDetail"] = None,
        description: "str" = None,
        useContext: list["UsageContext"] = None,
        jurisdiction: list["CodeableConcept"] = None,
    ):

        self.resourceType = "MetadataResource"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.url = url
        self.version = version
        self.name = name
        self.title = title
        self.status = status
        self.experimental = experimental
        self.date = date
        self.publisher = publisher
        self.contact = contact or []
        self.description = description
        self.useContext = useContext or []
        self.jurisdiction = jurisdiction or []

    @classmethod
    def from_dict(cls, data: dict) -> "MetadataResource":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MetadataResource":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for RelatedPerson. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.R4B.Address import *
from fhirmodels.R4B.Attachment import *
from fhirmodels.R4B.BackboneElement import *
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.ContactPoint import *
from fhirmodels.R4B.DomainResource import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.HumanName import *
from fhirmodels.R4B.Identifier import *
from fhirmodels.R4B.Meta import *
from fhirmodels.R4B.Narrative import *
from fhirmodels.R4B.Period import *
from fhirmodels.R4B.Reference import *
from fhirmodels.R4B.Resource import *


class Communication(FhirBaseModel):
    """A language which may be used to communicate with about the patient's health.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept language: The language which can be used to communicate with the patient about his or her health
    :param bool preferred: Language preference indicator
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "language": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        language: "CodeableConcept" = None,
        preferred: "bool" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.language = language
        self.preferred = preferred

    @classmethod
    def from_dict(cls, data: dict) -> "RelatedPerson":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "RelatedPerson":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class RelatedPerson(DomainResource):
    """Information about a person that is involved in the care for a patient, but who is not the target of healthcare, nor has a formal responsibility in the care process.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: A human identifier for this person
    :param bool active: Whether this related person's record is in active use
    :param Reference patient: The patient this person is related to
    :param CodeableConcept relationship: The nature of the relationship
    :param HumanName name: A name associated with the person
    :param ContactPoint telecom: A contact detail for the person
    :param str gender: male | female | other | unknown
    :param str birthDate: The date on which the related person was born
    :param Address address: Address where the related person can be contacted or visited
    :param Attachment photo: Image of the person
    :param Period period: Period of time that this relationship is considered valid
    :param Communication communication: A language which may be used to communicate with about the patient's health
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "patient": {"class_name": "Reference", "is_contained": False},
        "relationship": {"class_name": "CodeableConcept", "is_contained": False},
        "name": {"class_name": "HumanName", "is_contained": False},
        "telecom": {"class_name": "ContactPoint", "is_contained": False},
        "address": {"class_name": "Address", "is_contained": False},
        "photo": {"class_name": "Attachment", "is_contained": False},
        "period": {"class_name": "Period", "is_contained": False},
        "communication": {"class_name": "Communication", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        active: "bool" = None,
        patient: "Reference" = None,
        relationship: list["CodeableConcept"] = None,
        name: list["HumanName"] = None,
        telecom: list["ContactPoint"] = None,
        gender: "str" = None,
        birthDate: "str" = None,
        address: list["Address"] = None,
        photo: list["Attachment"] = None,
        period: "Period" = None,
        communication: list["Communication"] = None,
    ):

        self.resourceType = "RelatedPerson"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.active = active
        self.patient = patient
        self.relationship = relationship or []
        self.name = name or []
        self.telecom = telecom or []
        self.gender = gender
        self.birthDate = birthDate
        self.address = address or []
        self.photo = photo or []
        self.period = period
        self.communication = communication or []

    @classmethod
    def from_dict(cls, data: dict) -> "RelatedPerson":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "RelatedPerson":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for SupplyDelivery. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.R4B.BackboneElement import *
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.DomainResource import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Identifier import *
from fhirmodels.R4B.Meta import *
from fhirmodels.R4B.Narrative import *
from fhirmodels.R4B.Period import *
from fhirmodels.R4B.Quantity import *
from fhirmodels.R4B.Reference import *
from fhirmodels.R4B.Resource import *
from fhirmodels.R4B.Timing import *


class SuppliedItem(FhirBaseModel):
    """The item that is being delivered or has been supplied.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Quantity quantity: Amount dispensed
    :param CodeableConcept itemCodeableConcept: Medication, Substance, or Device supplied
    :param Reference itemReference: Medication, Substance, or Device supplied
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "quantity": {"class_name": "Quantity", "is_contained": False},
        "itemCodeableConcept": {"class_name": "CodeableConcept", "is_contained": False},
        "itemReference": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        quantity: "Quantity" = None,
        itemCodeableConcept: "CodeableConcept" = None,
        itemReference: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.quantity = quantity
        self.itemCodeableConcept = itemCodeableConcept
        self.itemReference = itemReference

    @classmethod
    def from_dict(cls, data: dict) -> "SupplyDelivery":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SupplyDelivery":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class SupplyDelivery(DomainResource):
    """Record of delivery of what is supplied.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: External identifier
    :param Reference basedOn: Fulfills plan, proposal or order
    :param Reference partOf: Part of referenced event
    :param str status: in-progress | completed | abandoned | entered-in-error
    :param Reference patient: Patient for whom the item is supplied
    :param CodeableConcept type: Category of dispense event
    :param SuppliedItem suppliedItem: The item that is delivered or supplied
    :param str occurrenceDateTime: When event occurred
    :param Period occurrencePeriod: When event occurred
    :param Timing occurrenceTiming: When event occurred
    :param Reference supplier: Dispenser
    :param Reference destination: Where the Supply was sent
    :param Reference receiver: Who collected the Supply
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "basedOn": {"class_name": "Reference", "is_contained": False},
        "partOf": {"class_name": "Reference", "is_contained": False},
        "patient": {"class_name": "Reference", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "suppliedItem": {"class_name": "SuppliedItem", "is_contained": True},
        "occurrencePeriod": {"class_name": "Period", "is_contained": False},
        "occurrenceTiming": {"class_name": "Timing", "is_contained": False},
        "supplier": {"class_name": "Reference", "is_contained": False},
        "destination": {"class_name": "Reference", "is_contained": False},
        "receiver": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        basedOn: list["Reference"] = None,
        partOf: list["Reference"] = None,
        status: "str" = None,
        patient: "Reference" = None,
        type: "CodeableConcept" = None,
        suppliedItem: "SuppliedItem" = None,
        occurrenceDateTime: "str" = None,
        occurrencePeriod: "Period" = None,
        occurrenceTiming: "Timing" = None,
        supplier: "Reference" = None,
        destination: "Reference" = None,
        receiver: list["Reference"] = None,
    ):

        self.resourceType = "SupplyDelivery"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.basedOn = basedOn or []
        self.partOf = partOf or []
        self.status = status
        self.patient = patient
        self.type = type
        self.suppliedItem = suppliedItem
        self.occurrenceDateTime = occurrenceDateTime
        self.occurrencePeriod = occurrencePeriod
        self.occurrenceTiming = occurrenceTiming
        self.supplier = supplier
        self.destination = destination
        self.receiver = receiver or []

    @classmethod
    def from_dict(cls, data: dict) -> "SupplyDelivery":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SupplyDelivery":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for InventoryItem. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.Address import *
from fhirmodels.R5.Annotation import *
from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.Coding import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Duration import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Quantity import *
from fhirmodels.R5.Range import *
from fhirmodels.R5.Ratio import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *


class Name(FhirBaseModel):
    """The item name(s) - the brand name, or common name, functional name, generic name.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Coding nameType: The type of name e.g. 'brand-name', 'functional-name', 'common-name'
    :param str language: The language used to express the item name
    :param str name: The name or designation of the item
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "nameType": {"class_name": "Coding", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        nameType: "Coding" = None,
        language: "str" = None,
        name: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.nameType = nameType
        self.language = language
        self.name = name

    @classmethod
    def from_dict(cls, data: dict) -> "InventoryItem":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "InventoryItem":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ResponsibleOrganization(FhirBaseModel):
    """Organization(s) responsible for the product.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept role: The role of the organization e.g. manufacturer, distributor, or other
    :param Reference organization: An organization that is associated with the item
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "role": {"class_name": "CodeableConcept", "is_contained": False},
        "organization": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        role: "CodeableConcept" = None,
        organization: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.role = role
        self.organization = organization

    @classmethod
    def from_dict(cls, data: dict) -> "InventoryItem":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "InventoryItem":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Description(FhirBaseModel):
    """The descriptive characteristics of the inventory item.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str language: The language that is used in the item description
    :param str description: Textual description of the item
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        language: "str" = None,
        description: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.language = language
        self.description = description

    @classmethod
    def from_dict(cls, data: dict) -> "InventoryItem":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "InventoryItem":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Association(FhirBaseModel):
    """Association with other items or products.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept associationType: The type of association between the device and the other item
    :param Reference relatedItem: The related item or product
    :param Ratio quantity: The quantity of the product in this product
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "associationType": {"class_name": "CodeableConcept", "is_contained": False},
        "relatedItem": {"class_name": "Reference", "is_contained": False},
        "quantity": {"class_name": "Ratio", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        associationType: "CodeableConcept" = None,
        relatedItem: "Reference" = None,
        quantity: "Ratio" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.associationType = associationType
        self.relatedItem = relatedItem
        self.quantity = quantity

    @classmethod
    def from_dict(cls, data: dict) -> "InventoryItem":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "InventoryItem":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Characteristic(FhirBaseModel):
    """The descriptive or identifying characteristics of the item.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept characteristicType: The characteristic that is being defined
    :param str valueString: The value of the attribute
    :param int valueInteger: The value of the attribute
    :param float valueDecimal: The value of the attribute
    :param bool valueBoolean: The value of the attribute
    :param str valueUrl: The value of the attribute
    :param str valueDateTime: The value of the attribute
    :param Quantity valueQuantity: The value of the attribute
    :param Range valueRange: The value of the attribute
    :param Ratio valueRatio: The value of the attribute
    :param Annotation valueAnnotation: The value of the attribute
    :param Address valueAddress: The value of the attribute
    :param Duration valueDuration: The value of the attribute
    :param CodeableConcept valueCodeableConcept: The value of the attribute
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "characteristicType": {"class_name": "CodeableConcept", "is_contained": False},
        "valueQuantity": {"class_name": "Quantity", "is_contained": False},
        "valueRange": {"class_name": "Range", "is_contained": False},
        "valueRatio": {"class_name": "Ratio", "is_contained": False},
        "valueAnnotation": {"class_name": "Annotation", "is_contained": False},
        "valueAddress": {"class_name": "Address", "is_contained": False},
        "valueDuration": {"class_name": "Duration", "is_contained": False},
        "valueCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        characteristicType: "CodeableConcept" = None,
        valueString: "str" = None,
        valueInteger: "int" = None,
        valueDecimal: "float" = None,
        valueBoolean: "bool" = None,
        valueUrl: "str" = None,
        valueDateTime: "str" = None,
        valueQuantity: "Quantity" = None,
        valueRange: "Range" = None,
        valueRatio: "Ratio" = None,
        valueAnnotation: "Annotation" = None,
        valueAddress: "Address" = None,
        valueDuration: "Duration" = None,
        valueCodeableConcept: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.characteristicType = characteristicType
        self.valueString = valueString
        self.valueInteger = valueInteger
        self.valueDecimal = valueDecimal
        self.valueBoolean = valueBoolean
        self.valueUrl = valueUrl
        self.valueDateTime = valueDateTime
        self.valueQuantity = valueQuantity
        self.valueRange = valueRange
        self.valueRatio = valueRatio
        self.valueAnnotation = valueAnnotation
        self.valueAddress = valueAddress
        self.valueDuration = valueDuration
        self.valueCodeableConcept = valueCodeableConcept

    @classmethod
    def from_dict(cls, data: dict) -> "InventoryItem":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "InventoryItem":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Instance(FhirBaseModel):
    """Instances or occurrences of the product.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Identifier identifier: The identifier for the physical instance, typically a serial number
    :param str lotNumber: The lot or batch number of the item
    :param str expiry: The expiry date or date and time for the product
    :param Reference subject: The subject that the item is associated with
    :param Reference location: The location that the item is associated with
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "location": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        lotNumber: "str" = None,
        expiry: "str" = None,
        subject: "Reference" = None,
        location: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.lotNumber = lotNumber
        self.expiry = expiry
        self.subject = subject
        self.location = location

    @classmethod
    def from_dict(cls, data: dict) -> "InventoryItem":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "InventoryItem":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class InventoryItem(DomainResource):
    """functional description of an inventory item used in inventory and supply-related workflows.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Business identifier for the inventory item
    :param str status: active | inactive | entered-in-error | unknown
    :param CodeableConcept category: Category or class of the item
    :param CodeableConcept code: Code designating the specific type of item
    :param Name name: The item name(s) - the brand name, or common name, functional name, generic name or others
    :param ResponsibleOrganization responsibleOrganization: Organization(s) responsible for the product
    :param Description description: Descriptive characteristics of the item
    :param CodeableConcept inventoryStatus: The usage status like recalled, in use, discarded
    :param CodeableConcept baseUnit: The base unit of measure - the unit in which the product is used or counted
    :param Quantity netContent: Net content or amount present in the item
    :param Association association: Association with other items or products
    :param Characteristic characteristic: Characteristic of the item
    :param Instance instance: Instances or occurrences of the product
    :param Reference productReference: Link to a product resource used in clinical workflows
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "name": {"class_name": "Name", "is_contained": True},
        "responsibleOrganization": {
            "class_name": "ResponsibleOrganization",
            "is_contained": True,
        },
        "description": {"class_name": "Description", "is_contained": True},
        "inventoryStatus": {"class_name": "CodeableConcept", "is_contained": False},
        "baseUnit": {"class_name": "CodeableConcept", "is_contained": False},
        "netContent": {"class_name": "Quantity", "is_contained": False},
        "association": {"class_name": "Association", "is_contained": True},
        "characteristic": {"class_name": "Characteristic", "is_contained": True},
        "instance": {"class_name": "Instance", "is_contained": True},
        "productReference": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        status: "str" = None,
        category: list["CodeableConcept"] = None,
        code: list["CodeableConcept"] = None,
        name: list["Name"] = None,
        responsibleOrganization: list["ResponsibleOrganization"] = None,
        description: "Description" = None,
        inventoryStatus: list["CodeableConcept"] = None,
        baseUnit: "CodeableConcept" = None,
        netContent: "Quantity" = None,
        association: list["Association"] = None,
        characteristic: list["Characteristic"] = None,
        instance: "Instance" = None,
        productReference: "Reference" = None,
    ):

        self.resourceType = "InventoryItem"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.status = status
        self.category = category or []
        self.code = code or []
        self.name = name or []
        self.responsibleOrganization = responsibleOrganization or []
        self.description = description
        self.inventoryStatus = inventoryStatus or []
        self.baseUnit = baseUnit
        self.netContent = netContent
        self.association = association or []
        self.characteristic = characteristic or []
        self.instance = instance
        self.productReference = productReference

    @classmethod
    def from_dict(cls, data: dict) -> "InventoryItem":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "InventoryItem":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for MolecularSequence. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.Attachment import *
from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Range import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *


class StartingSequence(FhirBaseModel):
    """A sequence that is used as a starting sequence to describe variants that are present in a sequence analyzed.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept genomeAssembly: The genome assembly used for starting sequence, e.g. GRCh38
    :param CodeableConcept chromosome: Chromosome Identifier
    :param CodeableConcept sequenceCodeableConcept: The reference sequence that represents the starting sequence
    :param str sequenceString: The reference sequence that represents the starting sequence
    :param Reference sequenceReference: The reference sequence that represents the starting sequence
    :param int windowStart: Start position of the window on the starting sequence
    :param int windowEnd: End position of the window on the starting sequence
    :param str orientation: sense | antisense
    :param str strand: watson | crick
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "genomeAssembly": {"class_name": "CodeableConcept", "is_contained": False},
        "chromosome": {"class_name": "CodeableConcept", "is_contained": False},
        "sequenceCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "sequenceReference": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        genomeAssembly: "CodeableConcept" = None,
        chromosome: "CodeableConcept" = None,
        sequenceCodeableConcept: "CodeableConcept" = None,
        sequenceString: "str" = None,
        sequenceReference: "Reference" = None,
        windowStart: "int" = None,
        windowEnd: "int" = None,
        orientation: "str" = None,
        strand: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.genomeAssembly = genomeAssembly
        self.chromosome = chromosome
        self.sequenceCodeableConcept = sequenceCodeableConcept
        self.sequenceString = sequenceString
        self.sequenceReference = sequenceReference
        self.windowStart = windowStart
        self.windowEnd = windowEnd
        self.orientation = orientation
        self.strand = strand

    @classmethod
    def from_dict(cls, data: dict) -> "MolecularSequence":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MolecularSequence":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Edit(FhirBaseModel):
    """Changes in sequence from the starting sequence.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param int start: Start position of the edit on the starting sequence
    :param int end: End position of the edit on the starting sequence
    :param str replacementSequence: Allele that was observed
    :param str replacedSequence: Allele in the starting sequence
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        start: "int" = None,
        end: "int" = None,
        replacementSequence: "str" = None,
        replacedSequence: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.start = start
        self.end = end
        self.replacementSequence = replacementSequence
        self.replacedSequence = replacedSequence

    @classmethod
    def from_dict(cls, data: dict) -> "MolecularSequence":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MolecularSequence":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Relative(FhirBaseModel):
    """A sequence defined relative to another sequence.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept coordinateSystem: Ways of identifying nucleotides or amino acids within a sequence
    :param int ordinalPosition: Indicates the order in which the sequence should be considered when putting multiple 'relative' elements together
    :param Range sequenceRange: Indicates the nucleotide range in the composed sequence when multiple 'relative' elements are used together
    :param StartingSequence startingSequence: A sequence used as starting sequence
    :param Edit edit: Changes in sequence from the starting sequence
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "coordinateSystem": {"class_name": "CodeableConcept", "is_contained": False},
        "sequenceRange": {"class_name": "Range", "is_contained": False},
        "startingSequence": {"class_name": "StartingSequence", "is_contained": True},
        "edit": {"class_name": "Edit", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        coordinateSystem: "CodeableConcept" = None,
        ordinalPosition: "int" = None,
        sequenceRange: "Range" = None,
        startingSequence: "StartingSequence" = None,
        edit: list["Edit"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.coordinateSystem = coordinateSystem
        self.ordinalPosition = ordinalPosition
        self.sequenceRange = sequenceRange
        self.startingSequence = startingSequence
        self.edit = edit or []

    @classmethod
    def from_dict(cls, data: dict) -> "MolecularSequence":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MolecularSequence":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class MolecularSequence(DomainResource):
    """Representation of a molecular sequence.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Unique ID for this particular sequence
    :param str type: aa | dna | rna
    :param Reference subject: Subject this sequence is associated too
    :param Reference focus: What the molecular sequence is about, when it is not about the subject of record
    :param Reference specimen: Specimen used for sequencing
    :param Reference device: The method for sequencing
    :param Reference performer: Who should be responsible for test result
    :param str literal: Sequence that was observed
    :param Attachment formatted: Embedded file or a link (URL) which contains content to represent the sequence
    :param Relative relative: A sequence defined relative to another sequence
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "focus": {"class_name": "Reference", "is_contained": False},
        "specimen": {"class_name": "Reference", "is_contained": False},
        "device": {"class_name": "Reference", "is_contained": False},
        "performer": {"class_name": "Reference", "is_contained": False},
        "formatted": {"class_name": "Attachment", "is_contained": False},
        "relative": {"class_name": "Relative", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        type: "str" = None,
        subject: "Reference" = None,
        focus: list["Reference"] = None,
        specimen: "Reference" = None,
        device: "Reference" = None,
        performer: "Reference" = None,
        literal: "str" = None,
        formatted: list["Attachment"] = None,
        relative: list["Relative"] = None,
    ):

        self.resourceType = "MolecularSequence"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.type = type
        self.subject = subject
        self.focus = focus or []
        self.specimen = specimen
        self.device = device
        self.performer = performer
        self.literal = literal
        self.formatted = formatted or []
        self.relative = relative or []

    @classmethod
    def from_dict(cls, data: dict) -> "MolecularSequence":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MolecularSequence":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for AdverseEvent. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.Annotation import *
from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Period import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *
from fhirmodels.R5.Timing import *


class Participant(FhirBaseModel):
    """Indicates who or what participated in the adverse event and how they were involved.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept function: Type of involvement
    :param Reference actor: Who was involved in the adverse event or the potential adverse event
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "function": {"class_name": "CodeableConcept", "is_contained": False},
        "actor": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        function: "CodeableConcept" = None,
        actor: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.function = function
        self.actor = actor

    @classmethod
    def from_dict(cls, data: dict) -> "AdverseEvent":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "AdverseEvent":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Causality(FhirBaseModel):
    """Information on the possible cause of the event.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept assessmentMethod: Method of evaluating the relatedness of the suspected entity to the event
    :param CodeableConcept entityRelatedness: Result of the assessment regarding the relatedness of the suspected entity to the event
    :param Reference author: Author of the information on the possible cause of the event
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "assessmentMethod": {"class_name": "CodeableConcept", "is_contained": False},
        "entityRelatedness": {"class_name": "CodeableConcept", "is_contained": False},
        "author": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        assessmentMethod: "CodeableConcept" = None,
        entityRelatedness: "CodeableConcept" = None,
        author: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.assessmentMethod = assessmentMethod
        self.entityRelatedness = entityRelatedness
        self.author = author

    @classmethod
    def from_dict(cls, data: dict) -> "AdverseEvent":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "AdverseEvent":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class SuspectEntity(FhirBaseModel):
    """Describes the entity that is suspected to have caused the adverse event.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept instanceCodeableConcept: Refers to the specific entity that caused the adverse event
    :param Reference instanceReference: Refers to the specific entity that caused the adverse event
    :param Causality causality: Information on the possible cause of the event
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "instanceCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "instanceReference": {"class_name": "Reference", "is_contained": False},
        "causality": {"class_name": "Causality", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        instanceCodeableConcept: "CodeableConcept" = None,
        instanceReference: "Reference" = None,
        causality: "Causality" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.instanceCodeableConcept = instanceCodeableConcept
        self.instanceReference = instanceReference
        self.causality = causality

    @classmethod
    def from_dict(cls, data: dict) -> "AdverseEvent":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "AdverseEvent":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ContributingFactor(FhirBaseModel):
    """The contributing factors suspected to have increased the probability or severity of the adverse event.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Reference itemReference: Item suspected to have increased the probability or severity of the adverse event
    :param CodeableConcept itemCodeableConcept: Item suspected to have increased the probability or severity of the adverse event
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "itemReference": {"class_name": "Reference", "is_contained": False},
        "itemCodeableConcept": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        itemReference: "Reference" = None,
        itemCodeableConcept: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.itemReference = itemReference
        self.itemCodeableConcept = itemCodeableConcept

    @classmethod
    def from_dict(cls, data: dict) -> "AdverseEvent":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "AdverseEvent":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class PreventiveAction(FhirBaseModel):
    """Preventive actions that contributed to avoiding the adverse event.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Reference itemReference: Action that contributed to avoiding the adverse event
    :param CodeableConcept itemCodeableConcept: Action that contributed to avoiding the adverse event
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "itemReference": {"class_name": "Reference", "is_contained": False},
        "itemCodeableConcept": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        itemReference: "Reference" = None,
        itemCodeableConcept: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.itemReference = itemReference
        self.itemCodeableConcept = itemCodeableConcept

    @classmethod
    def from_dict(cls, data: dict) -> "AdverseEvent":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "AdverseEvent":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class MitigatingAction(FhirBaseModel):
    """The ameliorating action taken after the adverse event occured in order to reduce the extent of harm.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Reference itemReference: Ameliorating action taken after the adverse event occured in order to reduce the extent of harm
    :param CodeableConcept itemCodeableConcept: Ameliorating action taken after the adverse event occured in order to reduce the extent of harm
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "itemReference": {"class_name": "Reference", "is_contained": False},
        "itemCodeableConcept": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        itemReference: "Reference" = None,
        itemCodeableConcept: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.itemReference = itemReference
        self.itemCodeableConcept = itemCodeableConcept

    @classmethod
    def from_dict(cls, data: dict) -> "AdverseEvent":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "AdverseEvent":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class SupportingInfo(FhirBaseModel):
    """Supporting information relevant to the event.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Reference itemReference: Subject medical history or document relevant to this adverse event
    :param CodeableConcept itemCodeableConcept: Subject medical history or document relevant to this adverse event
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "itemReference": {"class_name": "Reference", "is_contained": False},
        "itemCodeableConcept": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        itemReference: "Reference" = None,
        itemCodeableConcept: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.itemReference = itemReference
        self.itemCodeableConcept = itemCodeableConcept

    @classmethod
    def from_dict(cls, data: dict) -> "AdverseEvent":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "AdverseEvent":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class AdverseEvent(DomainResource):
    """An event (i.e. any change to current patient status) that may be related to unintended effects on a patient or research participant. The unintended effects may require additional monitoring, treatment, hospitalization, or may result in death. The AdverseEvent resource also extends to potential or avoided events that could have had such effects. There are two major domains where the AdverseEvent resource is expected to be used. One is in clinical care reported adverse events and the other is in reporting adverse events in clinical  research trial management.  Adverse events can be reported by healthcare providers, patients, caregivers or by medical products manufacturers.  Given the differences between these two concepts, we recommend consulting the domain specific implementation guides when implementing the AdverseEvent Resource. The implementation guides include specific extensions, value sets and constraints.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Business identifier for the event
    :param str status: in-progress | completed | entered-in-error | unknown
    :param str actuality: actual | potential
    :param CodeableConcept category: wrong-patient | procedure-mishap | medication-mishap | device | unsafe-physical-environment | hospital-aquired-infection | wrong-body-site
    :param CodeableConcept code: Event or incident that occurred or was averted
    :param Reference subject: Subject impacted by event
    :param Reference encounter: The Encounter associated with the start of the AdverseEvent
    :param str occurrenceDateTime: When the event occurred
    :param Period occurrencePeriod: When the event occurred
    :param Timing occurrenceTiming: When the event occurred
    :param str detected: When the event was detected
    :param str recordedDate: When the event was recorded
    :param Reference resultingEffect: Effect on the subject due to this event
    :param Reference location: Location where adverse event occurred
    :param CodeableConcept seriousness: Seriousness or gravity of the event
    :param CodeableConcept outcome: Type of outcome from the adverse event
    :param Reference recorder: Who recorded the adverse event
    :param Participant participant: Who was involved in the adverse event or the potential adverse event and what they did
    :param Reference study: Research study that the subject is enrolled in
    :param bool expectedInResearchStudy: Considered likely or probable or anticipated in the research study
    :param SuspectEntity suspectEntity: The suspected agent causing the adverse event
    :param ContributingFactor contributingFactor: Contributing factors suspected to have increased the probability or severity of the adverse event
    :param PreventiveAction preventiveAction: Preventive actions that contributed to avoiding the adverse event
    :param MitigatingAction mitigatingAction: Ameliorating actions taken after the adverse event occured in order to reduce the extent of harm
    :param SupportingInfo supportingInfo: Supporting information relevant to the event
    :param Annotation note: Comment on adverse event
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "encounter": {"class_name": "Reference", "is_contained": False},
        "occurrencePeriod": {"class_name": "Period", "is_contained": False},
        "occurrenceTiming": {"class_name": "Timing", "is_contained": False},
        "resultingEffect": {"class_name": "Reference", "is_contained": False},
        "location": {"class_name": "Reference", "is_contained": False},
        "seriousness": {"class_name": "CodeableConcept", "is_contained": False},
        "outcome": {"class_name": "CodeableConcept", "is_contained": False},
        "recorder": {"class_name": "Reference", "is_contained": False},
        "participant": {"class_name": "Participant", "is_contained": True},
        "study": {"class_name": "Reference", "is_contained": False},
        "suspectEntity": {"class_name": "SuspectEntity", "is_contained": True},
        "contributingFactor": {
            "class_name": "ContributingFactor",
            "is_contained": True,
        },
        "preventiveAction": {"class_name": "PreventiveAction", "is_contained": True},
        "mitigatingAction": {"class_name": "MitigatingAction", "is_contained": True},
        "supportingInfo": {"class_name": "SupportingInfo", "is_contained": True},
        "note": {"class_name": "Annotation", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        status: "str" = None,
        actuality: "str" = None,
        category: list["CodeableConcept"] = None,
        code: "CodeableConcept" = None,
        subject: "Reference" = None,
        encounter: "Reference" = None,
        occurrenceDateTime: "str" = None,
        occurrencePeriod: "Period" = None,
        occurrenceTiming: "Timing" = None,
        detected: "str" = None,
        recordedDate: "str" = None,
        resultingEffect: list["Reference"] = None,
        location: "Reference" = None,
        seriousness: "CodeableConcept" = None,
        outcome: list["CodeableConcept"] = None,
        recorder: "Reference" = None,
        participant: list["Participant"] = None,
        study: list["Reference"] = None,
        expectedInResearchStudy: "bool" = None,
        suspectEntity: list["SuspectEntity"] = None,
        contributingFactor: list["ContributingFactor"] = None,
        preventiveAction: list["PreventiveAction"] = None,
        mitigatingAction: list["MitigatingAction"] = None,
        supportingInfo: list["SupportingInfo"] = None,
        note: list["Annotation"] = None,
    ):

        self.resourceType = "AdverseEvent"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.status = status
        self.actuality = actuality
        self.category = category or []
        self.code = code
        self.subject = subject
        self.encounter = encounter
        self.occurrenceDateTime = occurrenceDateTime
        self.occurrencePeriod = occurrencePeriod
        self.occurrenceTiming = occurrenceTiming
        self.detected = detected
        self.recordedDate = recordedDate
        self.resultingEffect = resultingEffect or []
        self.location = location
        self.seriousness = seriousness
        self.outcome = outcome or []
        self.recorder = recorder
        self.participant = participant or []
        self.study = study or []
        self.expectedInResearchStudy = expectedInResearchStudy
        self.suspectEntity = suspectEntity or []
        self.contributingFactor = contributingFactor or []
        self.preventiveAction = preventiveAction or []
        self.mitigatingAction = mitigatingAction or []
        self.supportingInfo = supportingInfo or []
        self.note = note or []

    @classmethod
    def from_dict(cls, data: dict) -> "AdverseEvent":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "AdverseEvent":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Population. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.generator import FhirBaseModel
from fhirmodels.R4.CodeableConcept import *
from fhirmodels.R4.Extension import *
from fhirmodels.R4.Range import *


class Population(FhirBaseModel):
    """Base StructureDefinition for Population Type: A populatioof people with some set of grouping criteria.
    :param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Range ageRange: The age of the specific population
    :param CodeableConcept ageCodeableConcept: The age of the specific population
    :param CodeableConcept gender: The gender of the specific population
    :param CodeableConcept race: Race of the specific population
    :param CodeableConcept physiologicalCondition: The existing physiological conditions of the specific population to which this applies
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "ageRange": {"class_name": "Range", "is_contained": False},
        "ageCodeableConcept": {"class_name": "CodeableConcept", "is_contained": False},
        "gender": {"class_name": "CodeableConcept", "is_contained": False},
        "race": {"class_name": "CodeableConcept", "is_contained": False},
        "physiologicalCondition": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        ageRange: "Range" = None,
        ageCodeableConcept: "CodeableConcept" = None,
        gender: "CodeableConcept" = None,
        race: "CodeableConcept" = None,
        physiologicalCondition: "CodeableConcept" = None,
    ):

        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.ageRange = ageRange
        self.ageCodeableConcept = ageCodeableConcept
        self.gender = gender
        self.race = race
        self.physiologicalCondition = physiologicalCondition

    @classmethod
    def from_dict(cls, data: dict) -> "Population":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Population":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Product. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.generator import FhirBaseModel
from fhirmodels.R5.Annotation import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.Element import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Quantity import *
from fhirmodels.R5.Reference import *


class Instance(FhirBaseModel):
    """Conveys instance-level information about this product item. One or several physical, countable instances or occurrences of the product.:param Quantity quantity: The amount of items
    :param Identifier identifier: The identifier for the physical instance, typically a serial number
    :param str lotNumber: The identification of the batch or lot of the product
    :param str expiry: The expiry date or date and time for the product
    :param Reference subject: Individual the product is associated with, or which has used the product
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "quantity": {"class_name": "Quantity", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        quantity: "Quantity" = None,
        identifier: list["Identifier"] = None,
        lotNumber: "str" = None,
        expiry: "str" = None,
        subject: "Reference" = None,
    ):
        self.quantity = quantity
        self.identifier = identifier or []
        self.lotNumber = lotNumber
        self.expiry = expiry
        self.subject = subject

    @classmethod
    def from_dict(cls, data: dict) -> "Product":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Product":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Product(FhirBaseModel):
    """Logical Model: A pattern to be followed by resources that represent a product used in healthcare, for clinical or operational purposes.
    :param str status: active | inactive | entered-in-error
    :param CodeableConcept category: A category or class of the product
    :param CodeableConcept code: A code designating a specific type of product
    :param Reference manufacturer: Manufacturer, representative or officially responsible for the product
    :param Instance instance: One or several physical instances or occurrences of the product
    :param Annotation note: Comments made about the product
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "manufacturer": {"class_name": "Reference", "is_contained": False},
        "instance": {"class_name": "Instance", "is_contained": True},
        "note": {"class_name": "Annotation", "is_contained": False},
    }

    def __init__(
        self,
        status: "str" = None,
        category: list["CodeableConcept"] = None,
        code: "CodeableConcept" = None,
        manufacturer: list["Reference"] = None,
        instance: "Instance" = None,
        note: list["Annotation"] = None,
    ):

        self.status = status
        self.category = category or []
        self.code = code
        self.manufacturer = manufacturer or []
        self.instance = instance
        self.note = note or []

    @classmethod
    def from_dict(cls, data: dict) -> "Product":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Product":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for ExtendedContactDetail. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.generator import FhirBaseModel
from fhirmodels.R5.Address import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.ContactPoint import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.HumanName import *
from fhirmodels.R5.Period import *
from fhirmodels.R5.Reference import *


class ExtendedContactDetail(FhirBaseModel):
    """ExtendedContactDetail Type: Specifies contact information for a specific purpose over a period of time, might be handled/monitored by a specific named person or organization.
    :param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param CodeableConcept purpose: The type of contact
    :param HumanName name: Name of an individual to contact
    :param ContactPoint telecom: Contact details (e.g.phone/fax/url)
    :param Address address: Address for the contact
    :param Reference organization: This contact detail is handled/monitored by a specific organization
    :param Period period: Period that this contact was valid for usage
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "purpose": {"class_name": "CodeableConcept", "is_contained": False},
        "name": {"class_name": "HumanName", "is_contained": False},
        "telecom": {"class_name": "ContactPoint", "is_contained": False},
        "address": {"class_name": "Address", "is_contained": False},
        "organization": {"class_name": "Reference", "is_contained": False},
        "period": {"class_name": "Period", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        purpose: "CodeableConcept" = None,
        name: list["HumanName"] = None,
        telecom: list["ContactPoint"] = None,
        address: "Address" = None,
        organization: "Reference" = None,
        period: "Period" = None,
    ):

        self.id = id
        self.extension = extension or []
        self.purpose = purpose
        self.name = name or []
        self.telecom = telecom or []
        self.address = address
        self.organization = organization
        self.period = period

    @classmethod
    def from_dict(cls, data: dict) -> "ExtendedContactDetail":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ExtendedContactDetail":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for SubstanceReferenceInformation. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.R4.BackboneElement import *
from fhirmodels.R4.CodeableConcept import *
from fhirmodels.R4.DomainResource import *
from fhirmodels.R4.Extension import *
from fhirmodels.R4.Identifier import *
from fhirmodels.R4.Meta import *
from fhirmodels.R4.Narrative import *
from fhirmodels.R4.Quantity import *
from fhirmodels.R4.Range import *
from fhirmodels.R4.Reference import *
from fhirmodels.R4.Resource import *


class GeneElement(FhirBaseModel):
    """Todo.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: Todo
    :param Identifier element: Todo
    :param Reference source: Todo
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "element": {"class_name": "Identifier", "is_contained": False},
        "source": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        element: "Identifier" = None,
        source: list["Reference"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.element = element
        self.source = source or []

    @classmethod
    def from_dict(cls, data: dict) -> "SubstanceReferenceInformation":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstanceReferenceInformation":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Gene(FhirBaseModel):
    """Todo.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept geneSequenceOrigin: Todo
    :param CodeableConcept gene: Todo
    :param Reference source: Todo
    :param GeneElement geneElement: Todo
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "geneSequenceOrigin": {"class_name": "CodeableConcept", "is_contained": False},
        "gene": {"class_name": "CodeableConcept", "is_contained": False},
        "source": {"class_name": "Reference", "is_contained": False},
        "geneElement": {"class_name": "GeneElement", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        geneSequenceOrigin: "CodeableConcept" = None,
        gene: "CodeableConcept" = None,
        source: list["Reference"] = None,
        geneElement: list["GeneElement"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.geneSequenceOrigin = geneSequenceOrigin
        self.gene = gene
        self.source = source or []
        self.geneElement = geneElement or []

    @classmethod
    def from_dict(cls, data: dict) -> "SubstanceReferenceInformation":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstanceReferenceInformation":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Classification(FhirBaseModel):
    """Todo.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept domain: Todo
    :param CodeableConcept classification: Todo
    :param CodeableConcept subtype: Todo
    :param Reference source: Todo
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "domain": {"class_name": "CodeableConcept", "is_contained": False},
        "classification": {"class_name": "CodeableConcept", "is_contained": False},
        "subtype": {"class_name": "CodeableConcept", "is_contained": False},
        "source": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        domain: "CodeableConcept" = None,
        classification: "CodeableConcept" = None,
        subtype: list["CodeableConcept"] = None,
        source: list["Reference"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.domain = domain
        self.classification = classification
        self.subtype = subtype or []
        self.source = source or []

    @classmethod
    def from_dict(cls, data: dict) -> "SubstanceReferenceInformation":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstanceReferenceInformation":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Target(FhirBaseModel):
    """Todo.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Identifier target: Todo
    :param CodeableConcept type: Todo
    :param CodeableConcept interaction: Todo
    :param CodeableConcept organism: Todo
    :param CodeableConcept organismType: Todo
    :param Quantity amountQuantity: Todo
    :param Range amountRange: Todo
    :param str amountString: Todo
    :param CodeableConcept amountType: Todo
    :param Reference source: Todo
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "target": {"class_name": "Identifier", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "interaction": {"class_name": "CodeableConcept", "is_contained": False},
        "organism": {"class_name": "CodeableConcept", "is_contained": False},
        "organismType": {"class_name": "CodeableConcept", "is_contained": False},
        "amountQuantity": {"class_name": "Quantity", "is_contained": False},
        "amountRange": {"class_name": "Range", "is_contained": False},
        "amountType": {"class_name": "CodeableConcept", "is_contained": False},
        "source": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        target: "Identifier" = None,
        type: "CodeableConcept" = None,
        interaction: "CodeableConcept" = None,
        organism: "CodeableConcept" = None,
        organismType: "CodeableConcept" = None,
        amountQuantity: "Quantity" = None,
        amountRange: "Range" = None,
        amountString: "str" = None,
        amountType: "CodeableConcept" = None,
        source: list["Reference"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.target = target
        self.type = type
        self.interaction = interaction
        self.organism = organism
        self.organismType = organismType
        self.amountQuantity = amountQuantity
        self.amountRange = amountRange
        self.amountString = amountString
        self.amountType = amountType
        self.source = source or []

    @classmethod
    def from_dict(cls, data: dict) -> "SubstanceReferenceInformation":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstanceReferenceInformation":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class SubstanceReferenceInformation(DomainResource):
    """Todo.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param str comment: Todo
    :param Gene gene: Todo
    :param Classification classification: Todo
    :param Target target: Todo
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "gene": {"class_name": "Gene", "is_contained": True},
        "classification": {"class_name": "Classification", "is_contained": True},
        "target": {"class_name": "Target", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        comment: "str" = None,
        gene: list["Gene"] = None,
        classification: list["Classification"] = None,
        target: list["Target"] = None,
    ):

        self.resourceType = "SubstanceReferenceInformation"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.comment = comment
        self.gene = gene or []
        self.classification = classification or []
        self.target = target or []

    @classmethod
    def from_dict(cls, data: dict) -> "SubstanceReferenceInformation":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstanceReferenceInformation":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Medication. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.R4.BackboneElement import *
from fhirmodels.R4.CodeableConcept import *
from fhirmodels.R4.DomainResource import *
from fhirmodels.R4.Extension import *
from fhirmodels.R4.Identifier import *
from fhirmodels.R4.Meta import *
from fhirmodels.R4.Narrative import *
from fhirmodels.R4.Ratio import *
from fhirmodels.R4.Reference import *
from fhirmodels.R4.Resource import *


class Ingredient(FhirBaseModel):
    """Identifies a particular constituent of interest in the product.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept itemCodeableConcept: The actual ingredient or content
    :param Reference itemReference: The actual ingredient or content
    :param bool isActive: Active ingredient indicator
    :param Ratio strength: Quantity of ingredient present
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "itemCodeableConcept": {"class_name": "CodeableConcept", "is_contained": False},
        "itemReference": {"class_name": "Reference", "is_contained": False},
        "strength": {"class_name": "Ratio", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        itemCodeableConcept: "CodeableConcept" = None,
        itemReference: "Reference" = None,
        isActive: "bool" = None,
        strength: "Ratio" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.itemCodeableConcept = itemCodeableConcept
        self.itemReference = itemReference
        self.isActive = isActive
        self.strength = strength

    @classmethod
    def from_dict(cls, data: dict) -> "Medication":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Medication":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Batch(FhirBaseModel):
    """Information that only applies to packages (not products).:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str lotNumber: Identifier assigned to batch
    :param str expirationDate: When batch will expire
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        lotNumber: "str" = None,
        expirationDate: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.lotNumber = lotNumber
        self.expirationDate = expirationDate

    @classmethod
    def from_dict(cls, data: dict) -> "Medication":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Medication":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Medication(DomainResource):
    """This resource is primarily used for the identification and definition of a medication for the purposes of prescribing, dispensing, and administering a medication as well as for making statements about medication use.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Business identifier for this medication
    :param CodeableConcept code: Codes that identify this medication
    :param str status: active | inactive | entered-in-error
    :param Reference manufacturer: Manufacturer of the item
    :param CodeableConcept form: powder | tablets | capsule +
    :param Ratio amount: Amount of drug in package
    :param Ingredient ingredient: Active or inactive ingredient
    :param Batch batch: Details about packaged medications
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "manufacturer": {"class_name": "Reference", "is_contained": False},
        "form": {"class_name": "CodeableConcept", "is_contained": False},
        "amount": {"class_name": "Ratio", "is_contained": False},
        "ingredient": {"class_name": "Ingredient", "is_contained": True},
        "batch": {"class_name": "Batch", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        code: "CodeableConcept" = None,
        status: "str" = None,
        manufacturer: "Reference" = None,
        form: "CodeableConcept" = None,
        amount: "Ratio" = None,
        ingredient: list["Ingredient"] = None,
        batch: "Batch" = None,
    ):

        self.resourceType = "Medication"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.code = code
        self.status = status
        self.manufacturer = manufacturer
        self.form = form
        self.amount = amount
        self.ingredient = ingredient or []
        self.batch = batch

    @classmethod
    def from_dict(cls, data: dict) -> "Medication":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Medication":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Encounter. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.CodeableReference import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Duration import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Period import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *
from fhirmodels.R5.VirtualServiceDetail import *


class Participant(FhirBaseModel):
    """The list of people responsible for providing the service.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: Role of participant in encounter
    :param Period period: Period of time during the encounter that the participant participated
    :param Reference actor: The individual, device, or service participating in the encounter
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "period": {"class_name": "Period", "is_contained": False},
        "actor": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: list["CodeableConcept"] = None,
        period: "Period" = None,
        actor: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type or []
        self.period = period
        self.actor = actor

    @classmethod
    def from_dict(cls, data: dict) -> "Encounter":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Encounter":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Reason(FhirBaseModel):
    """The list of medical reasons that are expected to be addressed during the episode of care.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept use: What the reason value should be used for/as
    :param CodeableReference value: Reason the encounter takes place (core or reference)
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "use": {"class_name": "CodeableConcept", "is_contained": False},
        "value": {"class_name": "CodeableReference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        use: list["CodeableConcept"] = None,
        value: list["CodeableReference"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.use = use or []
        self.value = value or []

    @classmethod
    def from_dict(cls, data: dict) -> "Encounter":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Encounter":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Diagnosis(FhirBaseModel):
    """The list of diagnosis relevant to this encounter.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableReference condition: The diagnosis relevant to the encounter
    :param CodeableConcept use: Role that this diagnosis has within the encounter (e.g. admission, billing, discharge …)
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "condition": {"class_name": "CodeableReference", "is_contained": False},
        "use": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        condition: list["CodeableReference"] = None,
        use: list["CodeableConcept"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.condition = condition or []
        self.use = use or []

    @classmethod
    def from_dict(cls, data: dict) -> "Encounter":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Encounter":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Admission(FhirBaseModel):
    """Details about the stay during which a healthcare service is provided.

    This does not describe the event of admitting the patient, but rather any information that is relevant from the time of admittance until the time of discharge.:param str id: Unique id for inter-element referencing
        :param Extension extension: Additional content defined by implementations
        :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
        :param Identifier preAdmissionIdentifier: Pre-admission identifier
        :param Reference origin: The location/organization from which the patient came before admission
        :param CodeableConcept admitSource: From where patient was admitted (physician referral, transfer)
        :param CodeableConcept reAdmission: Indicates that the patient is being re-admitted
        :param Reference destination: Location/organization to which the patient is discharged
        :param CodeableConcept dischargeDisposition: Category or kind of location after discharge
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "preAdmissionIdentifier": {"class_name": "Identifier", "is_contained": False},
        "origin": {"class_name": "Reference", "is_contained": False},
        "admitSource": {"class_name": "CodeableConcept", "is_contained": False},
        "reAdmission": {"class_name": "CodeableConcept", "is_contained": False},
        "destination": {"class_name": "Reference", "is_contained": False},
        "dischargeDisposition": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        preAdmissionIdentifier: "Identifier" = None,
        origin: "Reference" = None,
        admitSource: "CodeableConcept" = None,
        reAdmission: "CodeableConcept" = None,
        destination: "Reference" = None,
        dischargeDisposition: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.preAdmissionIdentifier = preAdmissionIdentifier
        self.origin = origin
        self.admitSource = admitSource
        self.reAdmission = reAdmission
        self.destination = destination
        self.dischargeDisposition = dischargeDisposition

    @classmethod
    def from_dict(cls, data: dict) -> "Encounter":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Encounter":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Location(FhirBaseModel):
    """List of locations where  the patient has been during this encounter.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Reference location: Location the encounter takes place
    :param str status: planned | active | reserved | completed
    :param CodeableConcept form: The physical type of the location (usually the level in the location hierarchy - bed, room, ward, virtual etc.)
    :param Period period: Time period during which the patient was present at the location
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "location": {"class_name": "Reference", "is_contained": False},
        "form": {"class_name": "CodeableConcept", "is_contained": False},
        "period": {"class_name": "Period", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        location: "Reference" = None,
        status: "str" = None,
        form: "CodeableConcept" = None,
        period: "Period" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.location = location
        self.status = status
        self.form = form
        self.period = period

    @classmethod
    def from_dict(cls, data: dict) -> "Encounter":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Encounter":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Encounter(DomainResource):
    """An interaction between healthcare provider(s), and/or patient(s) for the purpose of providing healthcare service(s) or assessing the health status of patient(s).
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Identifier(s) by which this encounter is known
    :param str status: planned | in-progress | on-hold | discharged | completed | cancelled | discontinued | entered-in-error | unknown
    :param CodeableConcept _class: Classification of patient encounter context - e.g. Inpatient, outpatient
    :param CodeableConcept priority: Indicates the urgency of the encounter
    :param CodeableConcept type: Specific type of encounter (e.g. e-mail consultation, surgical day-care, ...)
    :param CodeableReference serviceType: Specific type of service
    :param Reference subject: The patient or group related to this encounter
    :param CodeableConcept subjectStatus: The current status of the subject in relation to the Encounter
    :param Reference episodeOfCare: Episode(s) of care that this encounter should be recorded against
    :param Reference basedOn: The request that initiated this encounter
    :param Reference careTeam: The group(s) that are allocated to participate in this encounter
    :param Reference partOf: Another Encounter this encounter is part of
    :param Reference serviceProvider: The organization (facility) responsible for this encounter
    :param Participant participant: List of participants involved in the encounter
    :param Reference appointment: The appointment that scheduled this encounter
    :param VirtualServiceDetail virtualService: Connection details of a virtual service (e.g. conference call)
    :param Period actualPeriod: The actual start and end time of the encounter
    :param str plannedStartDate: The planned start date/time (or admission date) of the encounter
    :param str plannedEndDate: The planned end date/time (or discharge date) of the encounter
    :param Duration length: Actual quantity of time the encounter lasted (less time absent)
    :param Reason reason: The list of medical reasons that are expected to be addressed during the episode of care
    :param Diagnosis diagnosis: The list of diagnosis relevant to this encounter
    :param Reference account: The set of accounts that may be used for billing for this Encounter
    :param CodeableConcept dietPreference: Diet preferences reported by the patient
    :param CodeableConcept specialArrangement: Wheelchair, translator, stretcher, etc
    :param CodeableConcept specialCourtesy: Special courtesies (VIP, board member)
    :param Admission admission: Details about the admission to a healthcare service
    :param Location location: List of locations where the patient has been
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "_class": {"class_name": "CodeableConcept", "is_contained": False},
        "priority": {"class_name": "CodeableConcept", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "serviceType": {"class_name": "CodeableReference", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "subjectStatus": {"class_name": "CodeableConcept", "is_contained": False},
        "episodeOfCare": {"class_name": "Reference", "is_contained": False},
        "basedOn": {"class_name": "Reference", "is_contained": False},
        "careTeam": {"class_name": "Reference", "is_contained": False},
        "partOf": {"class_name": "Reference", "is_contained": False},
        "serviceProvider": {"class_name": "Reference", "is_contained": False},
        "participant": {"class_name": "Participant", "is_contained": True},
        "appointment": {"class_name": "Reference", "is_contained": False},
        "virtualService": {"class_name": "VirtualServiceDetail", "is_contained": False},
        "actualPeriod": {"class_name": "Period", "is_contained": False},
        "length": {"class_name": "Duration", "is_contained": False},
        "reason": {"class_name": "Reason", "is_contained": True},
        "diagnosis": {"class_name": "Diagnosis", "is_contained": True},
        "account": {"class_name": "Reference", "is_contained": False},
        "dietPreference": {"class_name": "CodeableConcept", "is_contained": False},
        "specialArrangement": {"class_name": "CodeableConcept", "is_contained": False},
        "specialCourtesy": {"class_name": "CodeableConcept", "is_contained": False},
        "admission": {"class_name": "Admission", "is_contained": True},
        "location": {"class_name": "Location", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        status: "str" = None,
        _class: list["CodeableConcept"] = None,
        priority: "CodeableConcept" = None,
        type: list["CodeableConcept"] = None,
        serviceType: list["CodeableReference"] = None,
        subject: "Reference" = None,
        subjectStatus: "CodeableConcept" = None,
        episodeOfCare: list["Reference"] = None,
        basedOn: list["Reference"] = None,
        careTeam: list["Reference"] = None,
        partOf: "Reference" = None,
        serviceProvider: "Reference" = None,
        participant: list["Participant"] = None,
        appointment: list["Reference"] = None,
        virtualService: list["VirtualServiceDetail"] = None,
        actualPeriod: "Period" = None,
        plannedStartDate: "str" = None,
        plannedEndDate: "str" = None,
        length: "Duration" = None,
        reason: list["Reason"] = None,
        diagnosis: list["Diagnosis"] = None,
        account: list["Reference"] = None,
        dietPreference: list["CodeableConcept"] = None,
        specialArrangement: list["CodeableConcept"] = None,
        specialCourtesy: list["CodeableConcept"] = None,
        admission: "Admission" = None,
        location: list["Location"] = None,
    ):

        self.resourceType = "Encounter"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.status = status
        self._class = _class or []
        self.priority = priority
        self.type = type or []
        self.serviceType = serviceType or []
        self.subject = subject
        self.subjectStatus = subjectStatus
        self.episodeOfCare = episodeOfCare or []
        self.basedOn = basedOn or []
        self.careTeam = careTeam or []
        self.partOf = partOf
        self.serviceProvider = serviceProvider
        self.participant = participant or []
        self.appointment = appointment or []
        self.virtualService = virtualService or []
        self.actualPeriod = actualPeriod
        self.plannedStartDate = plannedStartDate
        self.plannedEndDate = plannedEndDate
        self.length = length
        self.reason = reason or []
        self.diagnosis = diagnosis or []
        self.account = account or []
        self.dietPreference = dietPreference or []
        self.specialArrangement = specialArrangement or []
        self.specialCourtesy = specialCourtesy or []
        self.admission = admission
        self.location = location or []

    @classmethod
    def from_dict(cls, data: dict) -> "Encounter":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Encounter":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for CatalogEntry. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.R4B.BackboneElement import *
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.DomainResource import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Identifier import *
from fhirmodels.R4B.Meta import *
from fhirmodels.R4B.Narrative import *
from fhirmodels.R4B.Period import *
from fhirmodels.R4B.Reference import *
from fhirmodels.R4B.Resource import *


class RelatedEntry(FhirBaseModel):
    """Used for example, to point to a substance, or to a device used to administer a medication.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str relationtype: triggers | is-replaced-by
    :param Reference item: The reference to the related item
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "item": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        relationtype: "str" = None,
        item: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.relationtype = relationtype
        self.item = item

    @classmethod
    def from_dict(cls, data: dict) -> "CatalogEntry":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "CatalogEntry":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class CatalogEntry(DomainResource):
    """Catalog entries are wrappers that contextualize items included in a catalog.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Unique identifier of the catalog item
    :param CodeableConcept type: The type of item - medication, device, service, protocol or other
    :param bool orderable: Whether the entry represents an orderable item
    :param Reference referencedItem: The item that is being defined
    :param Identifier additionalIdentifier: Any additional identifier(s) for the catalog item, in the same granularity or concept
    :param CodeableConcept classification: Classification (category or class) of the item entry
    :param str status: draft | active | retired | unknown
    :param Period validityPeriod: The time period in which this catalog entry is expected to be active
    :param str validTo: The date until which this catalog entry is expected to be active
    :param str lastUpdated: When was this catalog last updated
    :param CodeableConcept additionalCharacteristic: Additional characteristics of the catalog entry
    :param CodeableConcept additionalClassification: Additional classification of the catalog entry
    :param RelatedEntry relatedEntry: An item that this catalog entry is related to
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "referencedItem": {"class_name": "Reference", "is_contained": False},
        "additionalIdentifier": {"class_name": "Identifier", "is_contained": False},
        "classification": {"class_name": "CodeableConcept", "is_contained": False},
        "validityPeriod": {"class_name": "Period", "is_contained": False},
        "additionalCharacteristic": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "additionalClassification": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "relatedEntry": {"class_name": "RelatedEntry", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        type: "CodeableConcept" = None,
        orderable: "bool" = None,
        referencedItem: "Reference" = None,
        additionalIdentifier: list["Identifier"] = None,
        classification: list["CodeableConcept"] = None,
        status: "str" = None,
        validityPeriod: "Period" = None,
        validTo: "str" = None,
        lastUpdated: "str" = None,
        additionalCharacteristic: list["CodeableConcept"] = None,
        additionalClassification: list["CodeableConcept"] = None,
        relatedEntry: list["RelatedEntry"] = None,
    ):

        self.resourceType = "CatalogEntry"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.type = type
        self.orderable = orderable
        self.referencedItem = referencedItem
        self.additionalIdentifier = additionalIdentifier or []
        self.classification = classification or []
        self.status = status
        self.validityPeriod = validityPeriod
        self.validTo = validTo
        self.lastUpdated = lastUpdated
        self.additionalCharacteristic = additionalCharacteristic or []
        self.additionalClassification = additionalClassification or []
        self.relatedEntry = relatedEntry or []

    @classmethod
    def from_dict(cls, data: dict) -> "CatalogEntry":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "CatalogEntry":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for MedicinalProductContraindication. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.R4.BackboneElement import *
from fhirmodels.R4.CodeableConcept import *
from fhirmodels.R4.DomainResource import *
from fhirmodels.R4.Extension import *
from fhirmodels.R4.Meta import *
from fhirmodels.R4.Narrative import *
from fhirmodels.R4.Population import *
from fhirmodels.R4.Reference import *
from fhirmodels.R4.Resource import *


class OtherTherapy(FhirBaseModel):
    """Information about the use of the medicinal product in relation to other therapies described as part of the indication.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept therapyRelationshipType: The type of relationship between the medicinal product indication or contraindication and another therapy
    :param CodeableConcept medicationCodeableConcept: Reference to a specific medication (active substance, medicinal product or class of products) as part of an indication or contraindication
    :param Reference medicationReference: Reference to a specific medication (active substance, medicinal product or class of products) as part of an indication or contraindication
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "therapyRelationshipType": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "medicationCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "medicationReference": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        therapyRelationshipType: "CodeableConcept" = None,
        medicationCodeableConcept: "CodeableConcept" = None,
        medicationReference: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.therapyRelationshipType = therapyRelationshipType
        self.medicationCodeableConcept = medicationCodeableConcept
        self.medicationReference = medicationReference

    @classmethod
    def from_dict(cls, data: dict) -> "MedicinalProductContraindication":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicinalProductContraindication":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class MedicinalProductContraindication(DomainResource):
    """The clinical particulars - indications, contraindications etc. of a medicinal product, including for regulatory purposes.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Reference subject: The medication for which this is an indication
    :param CodeableConcept disease: The disease, symptom or procedure for the contraindication
    :param CodeableConcept diseaseStatus: The status of the disease or symptom for the contraindication
    :param CodeableConcept comorbidity: A comorbidity (concurrent condition) or coinfection
    :param Reference therapeuticIndication: Information about the use of the medicinal product in relation to other therapies as part of the indication
    :param OtherTherapy otherTherapy: Information about the use of the medicinal product in relation to other therapies described as part of the indication
    :param Population population: The population group to which this applies
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "disease": {"class_name": "CodeableConcept", "is_contained": False},
        "diseaseStatus": {"class_name": "CodeableConcept", "is_contained": False},
        "comorbidity": {"class_name": "CodeableConcept", "is_contained": False},
        "therapeuticIndication": {"class_name": "Reference", "is_contained": False},
        "otherTherapy": {"class_name": "OtherTherapy", "is_contained": True},
        "population": {"class_name": "Population", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        subject: list["Reference"] = None,
        disease: "CodeableConcept" = None,
        diseaseStatus: "CodeableConcept" = None,
        comorbidity: list["CodeableConcept"] = None,
        therapeuticIndication: list["Reference"] = None,
        otherTherapy: list["OtherTherapy"] = None,
        population: list["Population"] = None,
    ):

        self.resourceType = "MedicinalProductContraindication"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.subject = subject or []
        self.disease = disease
        self.diseaseStatus = diseaseStatus
        self.comorbidity = comorbidity or []
        self.therapeuticIndication = therapeuticIndication or []
        self.otherTherapy = otherTherapy or []
        self.population = population or []

    @classmethod
    def from_dict(cls, data: dict) -> "MedicinalProductContraindication":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicinalProductContraindication":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()
